@@ -17,12 +17,11 @@
  * 02111-1307, USA.
 **/
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include "config.h"
 
 #include <limits.h>
 #include <string.h>
+#include <sys/stat.h>
 
 #include <glib.h>
 #include <glib/gstdio.h>
@@ -75,7 +74,7 @@ struct _CopyThemeDialogPrivate
 	GtkWidget *current;
 	GtkWidget *from;
 	GtkWidget *to;
-	
+
 	GFile *theme_dir;
 	GSList *all_files, *file;
 	GSList *all_basenames, *basename;
@@ -303,7 +302,7 @@ add_file_to_dialog (gpointer data, gpointer user_data)
 		                                          uri);
 		g_free (uri);
 		gtk_window_set_title (GTK_WINDOW (dialog), "");
-		gtk_window_set_icon_name (GTK_WINDOW (dialog), "screensaver");
+		gtk_window_set_icon_name (GTK_WINDOW (dialog), "preferences-desktop-screensaver");
 		
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
